////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/*

Project 023 - Compass and Tilt
CCS compiler
		
Example for connecting an IC master with a 18F452 to read from the TD-CMP01 and TD-CMP02 ic slave modules (Compass with Tilt/Roll)


December 2005 - May 2006

www.techdesign.be
info@techdesign.be

*/
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#include <18f452.h>			// device selection 
#device *=16

#include <string.h>
#include <STDLIB.H>
#include <2401.c>		// for IC EXT.EEPROM emulation used by slave ic TD-CMP modules
 
#fuses HS,NOWDT,NOPROTECT,NOLVP,PUT,NOBROWNOUT,CCP2C1,NOSTVREN,NODEBUG,NOCPB,NOWRTB 

#use delay(clock=20000000) 	// 20 MhZ crystal oscillator // note: H4 (PLL) won't run below 4V2	// H4 (PLL) may need a 100R resistor between OSC2 & GND

#use rs232(baud=19200, xmit=PIN_C6, rcv=PIN_C7)
#use i2c(master, sda=PIN_C4, scl=PIN_C3, fast) 

#use fast_io(A)
#use fast_io(B)
#use fast_io(C)
#use fast_io(D)
#use fast_io(E)

#define NOP #asm nop #endasm

#byte pa	=0xF80	//port a	// 
#byte pb	=0xF81	//b			// 
#byte pc	=0xF82	//c			// 
#byte pd	=0xF83	//d			// usb port 8 bits parallel
#byte pe	=0xF84	//port e	// 

// *********************************
// PORT A
// 

#bit adjust		 	=pa.2		// use 10k pull-down resistor	
								// connect to + to adjust LCD contrast when booting, then release
								// value is stored in internal EEPROM


// *********************************
// PORT B: 
// 
#bit test_pin	 	=pb.0		//


// *********************************
// PORT C 
// RS232 and IC: already defined (hardware)

// RC3 pin18 = IC SCL		// already defined (hardware)	
// RC4 pin23 = IC SDA		// already defined (hardware)	

// RC6 pin25 = RS232 TX		// already defined (hardware)
// RC7 pin26 = RS232 RX		//


// *********************************
// PORT D
// lph7779-1 (nokia 3310 lcd)

											// LCD			pin 1= VDD
#bit nok_sclk 	=pd.5		// RD5=	pin28	// "	"	 	pin 2= SCLK
#bit nok_sda 	=pd.4		// RD4= pin27	// "	"		pin 3= SDA
#bit nok_dc 	=pd.3		// RD3= pin22	// "	"		pin 4= D/C
#bit nok_cs 	=pd.2		// RD2= pin21	// "	"		pin 5= CS
											// "	"		pin 6= GND
											// "	"		pin 7= Vout (+ of POL C. 047 // its - to GND)
#bit nok_res 	=pd.1		// RD1= pin20	// "	"		pin 8= RES


// *********************************
// PORT E
// 


// *********************************


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//
//
char char_row,charsel,charpos,chardata; 		// for the nokia_3310 lcd routines
char nokia_vop;
int16 ddram;
char plot_value;
int32 plot_value32;
int32 plot_umsb,plot_lmsb,plot_ulsb,plot_llsb;
#include <lph7779_v6.c>
//


#zero_ram

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//-------------------------------------------

void main()
{
SETUP_ADC(ADC_OFF);
setup_adc_ports( NO_ANALOGS );

SET_TRIS_A(0x1f);		// oooi iiii
SET_TRIS_B(0x00);		// oooo oooo	
SET_TRIS_C(0x90);		// iooi oooo
SET_TRIS_D(0xc1);		// iioo oooi	
SET_TRIS_E(0x07);		// oooo oiii	


//
//
printf("\n\n\r023 - TD-CMP I2C example \n\n\r");		// RS232 test
//
//
nokia_pre_init();
nokia_init();							// lph7779 init
nokia_post_init();

init_ext_eeprom();						// init TD-CMP module as slave IC ext.EEPROM


nokia_gotoxy(0,5);
printf(nokia_printchar,"023 TD-CMP I2C");

//
printf("init OK \n\r");		// RS232 test
//




/////////////////////////////////////////////


while(true){ 

int8 cmp_LLSB,cmp_ULSB;
int16 compass_degrees;
signed int8 adxl_x,tilt_degrees;
signed int8 adxl_y,roll_degrees;


test_pin=1;
delay_ms(250);

//////////////////////////////////////////////
///////			// TD-CMP compass ic reading

cmp_LLSB = READ_EXT_EEPROM(0x00);					// read TD-CMP register 0	(cmp_LLSB) 
cmp_ULSB = READ_EXT_EEPROM(0x01);					// read TD-CMP register 1	(cmp_ULSB) 

compass_degrees= ((int16)cmp_ULSB<<8)+cmp_LLSB;

nokia_gotoxy(0,0);
printf(nokia_printchar,"Compass= %3lu",compass_degrees);			// output to LCD
nokia_print_degree();
printf("\n\rCompass= %3lu",compass_degrees);						// output to RS232 


///////////////////////////////////////////
//////			// TD-CMP tilt ic reading	

adxl_x = READ_EXT_EEPROM(0x04);						// read TD-CMP register 4	(adxl_x) Tilt

tilt_degrees= adxl_x;

nokia_gotoxy(0,1);
printf(nokia_printchar,"Tilt= %3d",tilt_degrees);			// output to LCD
nokia_print_degree();
printf("   Tilt= %3d",tilt_degrees);						// output to RS232 


///////////////////////////////////////////
//////			// TD-CMP roll ic reading	

adxl_y = READ_EXT_EEPROM(0x05);						// read TD-CMP register 5	(adxl_y) Roll

roll_degrees= adxl_y;

nokia_gotoxy(0,2);
printf(nokia_printchar,"Roll= %3d",roll_degrees);			// output to LCD
nokia_print_degree();
printf("   Roll= %3d",roll_degrees);						// output to RS232 

///////////////////////////////////////////
//////





test_pin=0;
delay_ms(250);


			} 


}
//end main 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//													The End !!!!
